==> meecrowave-1.2.14-source-release.zip: meecrowave-1.2.14/meecrowave-core/src/test/java/org/superbiz/app/Init.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.superbiz.app;

import javax.servlet.DispatcherType;
import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletContainerInitializer;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.annotation.HandlesTypes;
import javax.ws.rs.Path;
import javax.ws.rs.core.Application;
import java.io.IOException;
import java.util.EnumSet;
import java.util.Set;

import static java.util.stream.Collectors.joining;

@HandlesTypes({Path.class, Application.class})
public class Init implements ServletContainerInitializer {
    @Override
    public void onStartup(final Set<Class<?>> c, final ServletContext ctx) throws ServletException {
        ctx.addFilter("sci", new Filter() {
            @Override
            public void init(final FilterConfig filterConfig) throws ServletException {
                // no-op
            }

            @Override
            public void doFilter(final ServletRequest request, final ServletResponse response, final FilterChain chain) throws IOException, ServletException {
                response.getWriter().write("sci:" + c.stream().map(Class::getName).sorted().collect(joining()));
            }

            @Override
            public void destroy() {
                // no-op
            }
        }).addMappingForUrlPatterns(EnumSet.allOf(DispatcherType.class), false, "/sci");
    }
}

==> meecrowave-2.0.0-source-release.zip: meecrowave-2.0.0/meecrowave-core/src/test/java/org/superbiz/app/Init.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.superbiz.app;

import jakarta.servlet.DispatcherType;
import jakarta.servlet.Filter;
import jakarta.servlet.FilterChain;
import jakarta.servlet.FilterConfig;
import jakarta.servlet.ServletContainerInitializer;
import jakarta.servlet.ServletContext;
import jakarta.servlet.ServletException;
import jakarta.servlet.ServletRequest;
import jakarta.servlet.ServletResponse;
import jakarta.servlet.annotation.HandlesTypes;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.core.Application;
import java.io.IOException;
import java.util.EnumSet;
import java.util.Set;

import static java.util.stream.Collectors.joining;

@HandlesTypes({Path.class, Application.class})
public class Init implements ServletContainerInitializer {
    @Override
    public void onStartup(final Set<Class<?>> c, final ServletContext ctx) throws ServletException {
        ctx.addFilter("sci", new Filter() {
            @Override
            public void init(final FilterConfig filterConfig) throws ServletException {
                // no-op
            }

            @Override
            public void doFilter(final ServletRequest request, final ServletResponse response, final FilterChain chain) throws IOException, ServletException {
                response.getWriter().write("sci:" + c.stream().map(Class::getName).sorted().collect(joining()));
            }

            @Override
            public void destroy() {
                // no-op
            }
        }).addMappingForUrlPatterns(EnumSet.allOf(DispatcherType.class), false, "/sci");
    }
}
